#
# spec file for package sc-controller
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sc-controller
Version:        0.4.8.8
Release:        bp155.1.6
Summary:        User-mode driver and GTK3-based GUI for the Steam Controller
License:        GPL-2.0-only
Group:          Hardware/Joystick
URL:            https://github.com/Ryochan7/sc-controller
Source:         %{URL}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  python3-setuptools
BuildRequires:  shared-mime-info
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(udev)
Requires:       python3-evdev
Requires:       python3-gobject-Gdk
Requires:       python3-pycairo
Requires:       python3-pylibacl
Requires:       python3-setuptools

%description
Application allowing to setup, configure and use the Steam Controller
without using the Steam client.

%prep
%setup -q

%build
python3 setup.py build

%install
python3 setup.py install --root=%{buildroot} --optimize=1

%fdupes %{buildroot}%{_prefix}

%files
%license LICENSE
%doc README.md ADDITIONAL-LICENSES TODO.md
%{_bindir}/*
%{python3_sitearch}/*
%{_datadir}/applications/*
%{_datadir}/pixmaps/*
%{_datadir}/scc/
%{_datadir}/mime/packages/*
%{_datadir}/icons/hicolor/*
%{_udevrulesdir}/69-sc-controller.rules

%changelog
* Sun Oct  9 2022 Jannik Seiler <seil0@mosad.xyz>
- Update to 0.4.8.8
  * Merged latest changes from upstream Kozec repo. Steam Deck support added
  * Fixed AppImage build script
  * Fixed TypeError with Autoswitch Options menu item in OSD
  * Fixed RPAD icon display in main window
* Fri May  6 2022 Jannik Seiler <seil0@mosad.xyz>
- Update to 0.4.8.7
  * AppImage tested on Ubuntu 22.04 LTS, Fedora 35, Fedora 33,
    Manjaro, and PopOS 21.10
  * Updated AppImage scripts for setuptools behavior changes and
    library path changes
  * Migrate setup.py script to use setuptools rather than distutils.
    Try to comply with PEP 632 regarding the deprecation of distutils
  * Fixed Turn Off Controller option for BLE connected controller.
    Contribution by labsin
  * Changed feel of rumble emulation support. Period and amplitude of
    haptics change depending on data in ff_rumble event struct.
    I find that it feels better
  * Fixed long packet support for BLE reader. 3 input packet payloads
    now work in BLE reader
  * Fixed hotplug detection for BT connected Steam Controller
  * Added report ID 3 to feature report packets to allow BLE support to
    work again. Needed to make BLE support work with later versions of BlueZ (5.64)
  * Fixes to allow Bluetooth evdev and HID controllers to appear in
    controller registration list. Contribution by chewi
  * Fixed some HID driver and evdev driver crashes. Contribution by Alastor27
  * Fixed popup positioning and layering (somewhat) on Wayland.
    Contribution by Supreeeme
  * Allow deadzone calculations for analog trigger output.
    Full usable analog trigger range
  * Fixed Mouse Region output
  * Small fixes for HID report parsing
  * Added lowercase VDF button aliases to button dictionary
  * Properly clamp rotated touchpad coordinates to s16 range
  * Use proper limits for output 360 axes
  * Add DS4 v.1 detection to ds4drv driver
  * Fix display names for mapped X and Y buttons due to busted Linux aliases
* Thu Sep  9 2021 Jannik Seiler <seil0@mosad.xyz>
- Update to 0.4.8.6
  * Fixed initial Import Steam Profiles display list
  * Added python-vdf to AppImage build script
  * Fixed inputs tests. Contribution by rnhmjoj
  * Changed device config flags for Steam Controller to read accel
    data from controller
  * Added Steam Controller accel data in cemuhook. Fixes controller
    orientation in CemuHook
  * Disabled gyro action for default Desktop profile. CemuHook should
    not be needed for the Desktop profile
* Fri Jul 16 2021 Jannik Seiler <seil0@mosad.xyz>
- Update to 0.4.8.5
  * Fixed AttributeError problems in sccdaemon.py. Contribution by Alastor27
  * Fixed using two Steam Controllers in daemon. Contribution by berarma
  * Added toggled handler for 'Minimize to tray on start' checkbox
    in Settings. Contribution by Alastor27
  * Fixed 'Edit Bindings' and 'Autoswitcher Options' OSD options.
    Contribution by Supreeeme
  * Fixed importing VDFs from Steam. Contribution by Supreeeme
  * Changes to adjust mouse cursor movement based on gamepad poll rate.
    Allows more uniform mouse cursor movement between wired and
    wireless Steam Controllers
  * Now clear mouse cursor distance remainders when changing directions
* Wed Apr 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 0.4.8.4
  * Fixes for axis detection
- Use SourceUrl instead of _service
* Mon Mar  1 2021 Jannik Seiler <seil0@mosad.xyz>
- Updated to current git version
  * Fixed more issues related to Python 3 changes
  * BT support fixed. Contribution by claudius
  * Fixed invalid namespace issue with portions of OSD.
    Fixed Current Binding Display portion of OSD
  * Make sure daemon socket endpoint uses read-write mode rather
    than read-only. Contribution by aqxa1
* Fri Oct 23 2020 Jannik Seiler <seil0@mosad.xyz>
- Updated to current git version
  * Initial Python 3 port
  * Fixed several errors discovered by pyflakes
  * Updated Linux platform SDL GameController mappings from SDL_GameControllerDB project
* Tue Jul  7 2020 Jannik Seiler <seil0@mosad.xyz>
- Updated to current git version
  * Change decoration_layout property for GtkHeaderBar. Disable window icon.
    Removes double icon problem when run in Plasma
* Mon Jun  1 2020 Ferdinand Thiessen <rpm@fthiessen.de>
- Updated to current git version (Ryochan7's Python3 port)
- Set git version as version suffix
* Sun May 10 2020 Jannik Seiler <seil0@mosad.xyz>
- Update to @Ryochan7 Python 3 port
* Tue Jul  9 2019 Jannik Seiler <seil0@mosad.xyz>
- Update to version 0.4.7
  * Added option to send gyroscope data to Citra and Cemu (Cemuhook support)
  * Fixes in 0.4.7:
  * Not minimizing to tray on start
  * Issues when using stick simultaneously with lpad
  * Crash in controller registration dialog if udev device has special symbols in name (thanks @Verequies)
  * Trackball friction resets when set to zero
* Fri Dec 28 2018 Jannik Seiler <seil0@mosad.xyz>
- Update to version 0.4.6.1
  * Backups created while converting profiles were not ignored by GUI nor when converting profiles, creating more and more backups every time application started.
  * New in 0.4.6:
  * Added support for Retroarch RemotePad protocol, which allows using mobile phone as additional controller. See this wiki page for more info.
  * Added option to use shell command as condition in modeshift (#427)
  * Fixes in 0.4.6:
  * Proton (Steam Play) crashing scc-daemon (#435)
* Tue Nov 20 2018 Dominique Leuenberger <dimstar@opensuse.org>
- Fix dependencies by means of introspection (boo#1116778):
  + Add gobject-introspection BuildRequires: since the code is
    written with gobject-introspection in mind, having the BR adds
    a set of rpm provides/requires based on code inspection
  + Drop typelib-1-0-Rsvg-2_0 requires: with g-i above in place,
    this dependency is autodetected.
  + Replace python-gobject requires with python-gobject-Gdk: since
    this is a GUI tool, we need the Gdk/Gtk-part of pygobject in
    plus.
* Sun Nov  4 2018 seil0@mosad.xyz
- Update to version 0.4.5
  * On-screen keyboard can be now used with DS4 gamepad
  * Improved editing profile using controller
  * Allowed SVG custom menu icons
  * Allowed displaying multiple OSD messages, with different font size and display time
  * Fixes:
  * Status icon displaying wrong application name and/or no image
  * Status icon looks bad on hidpi screens
  * With two displays, where one is rotated and other one is offseted horizontally (and Compiz is used on 3rd Friday in month while gray cat is in house), OSD menu with too many items is drawn partially off-screen
  * Bumpers swapped with bluetooth driver
  * More NixOS fixes
- dropped desktop-file.patch, fixed upstream
* Wed Jan 25 2017 jengelh@inai.de
- Fixes to descriptions
* Sun Jan 22 2017 mailaender@opensuse.org
- initial packaging of version 0.3.6.2
